@@ -16,7 +16,7 @@ use Try::Catch;
 use Inline 'C';
 
 # Set the package version. 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 # Base class of this module.
 our @ISA = qw(Exporter);
@@ -468,7 +468,10 @@ __C__
 /* Pointer to the termios structure. */
 struct termios term;
 
-/* Define the function on_echo(). */
+/*
+ * Function: on_echo()
+ * -------------------
+ */
 int on_echo() {
     /* Read attributes, modify attributes and write attributes back. */
     tcgetattr(fileno(stdin), &term);
@@ -478,7 +481,10 @@ int on_echo() {
     return 1;
 };
 
-/* Define the function off_echo(). */
+/*
+ * Function: off_echo()
+ * --------------------
+ */
 int off_echo() {
     /* Read attributes, modify attributes and write attributes back. */
     tcgetattr(fileno(stdin), &term);
@@ -489,6 +495,10 @@ int off_echo() {
 };
 
 /* Define the function io_on(). */
+/* 
+ * Function: io_on()
+ * -----------------
+ */
 int io_on() {
     /* Read attributes, modify attributes and write attributes back. */
     tcgetattr(fileno(stdin), &term);
@@ -498,7 +508,10 @@ int io_on() {
     return 1;
 }
 
-/* Define the function io_off(). */
+/* 
+ * Function: io_off()
+ * ------------------
+ */
 int io_off() {
     /* Read attributes, modify attributes and write attributes back. */
     tcgetattr(fileno(stdin), &term);
@@ -514,11 +527,12 @@ int io_off() {
  *
  * Cast short integer variables to string variables of type char.
  *
- * args:
+ * Args:
  *     len    int       Length of value
  *     value  uint16_t  Short integer number
  *
- * returns:   String
+ * Returns:  
+ *     str    char*     Integer as string
  */
 char* int_str(int len, uint16_t value) {
     /* Allocate memory for the string variable. */   
@@ -552,7 +566,7 @@ int winsize_ic(SV* var1, SV* var2, SV* var3, SV* var4) {
     char* str2 = int_str(len2, ws.ws_col);
     int len3 = snprintf(NULL, 0, "%d", ws.ws_xpixel);
     char* str3 = int_str(len3, ws.ws_xpixel);
-    int len4 = int_len(ws.ws_ypixel);
+    int len4 = snprintf(NULL, 0, "%d", ws.ws_ypixel);
     char* str4 = snprintf(NULL, 0, "%d", ws.ws_ypixel);
     /* Set var1 to var4. */
     sv_setpvn(var1, str1, len1);
